## Phoenix Stenotype

The default stenotype system in Plover translates words like `KATD` as *catted* when it shouldn't translate at all.

Of course you can just use `plover-minimal-english-stenotype`, but this plugin includes certain orthography rules that are compatible with the Phoenix dictionary for convenience.

 This plugin allows you to type words like *embiggening* (automatically doubling the letter g) without defining a new dictionary entry, for example. It also enables you to write words like *ladies* and *occurred* in three separate strokes—If you decide to do that for some reason.
